@@ -15,6 +15,7 @@
 
 """The share type API controller module.."""
 
+from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
 import six
@@ -30,6 +31,9 @@ from manila import rpc
 from manila.share import share_types
 
 
+LOG = log.getLogger(__name__)
+
+
 class ShareTypesController(wsgi.Controller):
     """The share types API controller for the OpenStack API."""
 
@@ -67,7 +71,7 @@ class ShareTypesController(wsgi.Controller):
         """Return a single share type item."""
         context = req.environ['manila.context']
         try:
-            share_type = share_types.get_share_type(context, id)
+            share_type = self._show_share_type_details(context, id)
         except exception.NotFound:
             msg = _("Share type not found.")
             raise exc.HTTPNotFound(explanation=msg)
@@ -76,6 +80,19 @@ class ShareTypesController(wsgi.Controller):
         req.cache_db_share_type(share_type)
         return self._view_builder.show(req, share_type)
 
+    def _show_share_type_details(self, context, id):
+        share_type = share_types.get_share_type(context, id)
+        required_extra_specs = {}
+        try:
+            required_extra_specs = share_types.get_valid_required_extra_specs(
+                share_type['extra_specs'])
+        except exception.InvalidExtraSpec:
+            LOG.exception('Share type %(share_type_id)s has invalid required'
+                          ' extra specs.', {'share_type_id': id})
+
+        share_type['required_extra_specs'] = required_extra_specs
+        return share_type
+
     @wsgi.Controller.authorize
     def default(self, req):
         """Return default volume type."""
@@ -143,8 +160,8 @@ class ShareTypesController(wsgi.Controller):
         """Creates a new share type."""
         context = req.environ['manila.context']
 
-        if not self.is_valid_body(body, 'share_type') and \
-                not self.is_valid_body(body, 'volume_type'):
+        if (not self.is_valid_body(body, 'share_type') and
+                not self.is_valid_body(body, 'volume_type')):
             raise webob.exc.HTTPBadRequest()
 
         elif self.is_valid_body(body, 'share_type'):
