@@ -30,9 +30,11 @@ import manila.common.config
 import manila.compute
 import manila.compute.nova
 import manila.coordination
+import manila.data.helper
 import manila.db.api
 import manila.db.base
 import manila.exception
+import manila.message.api
 import manila.network
 import manila.network.linux.interface
 import manila.network.neutron.api
@@ -50,7 +52,7 @@ import manila.scheduler.weighers.pool
 import manila.service
 import manila.share.api
 import manila.share.driver
-import manila.share.drivers.cephfs.cephfs_native
+import manila.share.drivers.cephfs.driver
 import manila.share.drivers.container.driver
 import manila.share.drivers.container.storage_helper
 import manila.share.drivers.dell_emc.driver
@@ -85,7 +87,7 @@ import manila.share.hook
 import manila.share.manager
 import manila.volume
 import manila.volume.cinder
-import manila.wsgi
+import manila.wsgi.eventlet_server
 
 
 # List of *all* options in [DEFAULT] namespace of manila.
@@ -99,21 +101,24 @@ _global_opt_lists = [
     manila.common.config.global_opts,
     manila.compute._compute_opts,
     manila.coordination.coordination_opts,
+    manila.data.helper.data_helper_opts,
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
+    manila.message.api.messages_opts,
     manila.network.linux.interface.OPTS,
     manila.network.network_opts,
+    manila.network.network_base_opts,
+    manila.network.neutron.neutron_network_plugin.
+    neutron_network_plugin_opts,
+    manila.network.neutron.neutron_network_plugin.
+    neutron_single_network_plugin_opts,
     manila.network.neutron.neutron_network_plugin.
     neutron_bind_network_plugin_opts,
     manila.network.neutron.neutron_network_plugin.
     neutron_binding_profile,
     manila.network.neutron.neutron_network_plugin.
     neutron_binding_profile_opts,
-    manila.network.neutron.neutron_network_plugin.
-    neutron_network_plugin_opts,
-    manila.network.neutron.neutron_network_plugin.
-    neutron_single_network_plugin_opts,
     manila.network.standalone_network_plugin.standalone_network_plugin_opts,
     manila.quota.quota_opts,
     manila.scheduler.drivers.base.scheduler_driver_opts,
@@ -129,7 +134,7 @@ _global_opt_lists = [
     manila.share.driver.share_opts,
     manila.share.driver.ssh_opts,
     manila.share.drivers_private_data.private_data_opts,
-    manila.share.drivers.cephfs.cephfs_native.cephfs_native_opts,
+    manila.share.drivers.cephfs.driver.cephfs_opts,
     manila.share.drivers.container.driver.container_opts,
     manila.share.drivers.container.storage_helper.lv_opts,
     manila.share.drivers.dell_emc.driver.EMC_NAS_OPTS,
@@ -171,8 +176,7 @@ _global_opt_lists = [
     manila.share.hook.hook_options,
     manila.share.manager.share_manager_opts,
     manila.volume._volume_opts,
-    manila.wsgi.eventlet_opts,
-    manila.wsgi.socket_opts,
+    manila.wsgi.eventlet_server.socket_opts,
 ]
 
 _opts = [
