@@ -177,7 +177,7 @@ class BaseSharesTest(test.BaseTestCase):
             project_network_cidr=CONF.network.project_network_cidr,
             project_network_mask_bits=CONF.network.project_network_mask_bits,
             public_network_id=CONF.network.public_network_id,
-            resource_prefix=CONF.resources_prefix,
+            resource_prefix='tempest',
             identity_admin_endpoint_type=identity_admin_endpoint_type,
             identity_uri=identity_uri)
 
@@ -1047,6 +1047,27 @@ class BaseSharesAdminTest(BaseSharesTest):
     """Base test case class for all Shares Admin API tests."""
     credentials = ('admin', )
 
+    @classmethod
+    def setup_clients(cls):
+        super(BaseSharesAdminTest, cls).setup_clients()
+        # Initialise share clients
+        cls.admin_shares_v2_client = cls.os_admin.share_v2.SharesV2Client()
+
+    @classmethod
+    def _create_share_type(cls, specs=None):
+        name = data_utils.rand_name("unique_st_name")
+        extra_specs = cls.add_extra_specs_to_dict(specs)
+        return cls.create_share_type(
+            name, extra_specs=extra_specs,
+            client=cls.admin_shares_v2_client)['share_type']
+
+    @classmethod
+    def _create_share_group_type(cls):
+        share_group_type_name = data_utils.rand_name("unique_sgtype_name")
+        return cls.create_share_group_type(
+            name=share_group_type_name, share_types=[cls.share_type_id],
+            client=cls.admin_shares_v2_client)
+
 
 class BaseSharesMixedTest(BaseSharesTest):
     """Base test case class for all Shares API tests with all user roles."""
@@ -1075,3 +1096,25 @@ class BaseSharesMixedTest(BaseSharesTest):
                 cls.alt_shares_v2_client, cls.os_alt.networks_client)
             cls.alt_shares_client.share_network_id = alt_share_network_id
             cls.alt_shares_v2_client.share_network_id = alt_share_network_id
+
+            resource = {
+                "type": "share_network",
+                "id": alt_share_network_id,
+                "client": cls.alt_shares_v2_client,
+            }
+            cls.class_resources.insert(0, resource)
+
+    @classmethod
+    def _create_share_type(cls, specs=None):
+        name = data_utils.rand_name("unique_st_name")
+        extra_specs = cls.add_extra_specs_to_dict(specs)
+        return cls.create_share_type(
+            name, extra_specs=extra_specs,
+            client=cls.admin_shares_v2_client)['share_type']
+
+    @classmethod
+    def _create_share_group_type(cls):
+        share_group_type_name = data_utils.rand_name("unique_sgtype_name")
+        return cls.create_share_group_type(
+            name=share_group_type_name, share_types=[cls.share_type_id],
+            client=cls.admin_shares_v2_client)
