@@ -98,8 +98,16 @@ class SecurityServiceListMixin(object):
                                 in search_opts.items()))
 
 
-class SecurityServicesTest(base.BaseSharesTest,
+class SecurityServicesTest(base.BaseSharesMixedTest,
                            SecurityServiceListMixin):
+
+    @classmethod
+    def resource_setup(cls):
+        super(SecurityServicesTest, cls).resource_setup()
+        # create share type
+        cls.share_type = cls._create_share_type()
+        cls.share_type_id = cls.share_type['id']
+
     def setUp(self):
         super(SecurityServicesTest, self).setUp()
         ss_ldap_data = {
@@ -175,8 +183,9 @@ class SecurityServicesTest(base.BaseSharesTest,
         # that fails on wrong data, we expect error here.
         # We require any share that uses our share-network.
         try:
-            self.create_share(
-                share_network_id=fresh_sn["id"], cleanup_in_class=False)
+            self.create_share(share_type_id=self.share_type_id,
+                              share_network_id=fresh_sn["id"],
+                              cleanup_in_class=False)
         except Exception as e:
             # we do wait for either 'error' or 'available' status because
             # it is the only available statuses for proper deletion.
@@ -200,3 +209,11 @@ class SecurityServicesTest(base.BaseSharesTest,
         self.assertTrue(any(self.ss_ldap['id'] == ss['id'] for ss in listed))
         self.assertTrue(any(self.ss_kerberos['id'] == ss['id']
                             for ss in listed))
+
+    @tc.attr(base.TAG_POSITIVE, base.TAG_API)
+    def test_try_list_security_services_all_tenants(self):
+        listed = self.shares_client.list_security_services(
+            params={'all_tenants': 1})
+        self.assertTrue(any(self.ss_ldap['id'] == ss['id'] for ss in listed))
+        self.assertTrue(any(self.ss_kerberos['id'] == ss['id']
+                            for ss in listed))
